@@ -48,10 +48,12 @@ $worddensity = $this->GetPreference('key_density','3');
 $checkContent = $curcontent->GetPropertyValue('content_en');
 
 if ($checkContent != '') {
-    foreach ($contentVar as $key => $countVar) {
-        $countVars[] = $smarty->get_template_vars($countVar);
+    if ($contentVar != '') {
+        foreach ($contentVar as $key => $countVar) {
+            $countVars[] = $smarty->get_template_vars($countVar);
+        }
+        $countVars = join(' ', $countVars);
     }
-    $countVars = join(' ', $countVars);
     $contentBasic = $curcontent->GetPropertyValue('content_en');
     $keywords = $contentBasic . $countVars;
     $keywords = preg_replace('/[\n\r]/','',$keywords);
@@ -148,10 +150,12 @@ if ($curcontent->GetPropertyValue($description_block) != '') {
     $desc = htmlentities($desc, ENT_COMPAT, 'UTF-8');
     $desc = utf8_encode(html_entity_decode($desc));
 } elseif ($this->GetPreference('auto_title','1') == 1 && $curcontent->GetPropertyValue($description_block) == '') {
-    foreach ($contentVar as $key => $countVar2) {
-        $countVars2[] = $smarty->get_template_vars($countVar2);
+    if ($contentVar != '') {
+        foreach ($contentVar as $key => $countVar2) {
+            $countVars2[] = $smarty->get_template_vars($countVar2);
+        }
+        $countVars2 = join(' ', $countVars2);
     }
-    $countVars2 = join(' ', $countVars2);
     $contentBasic2 = $curcontent->GetPropertyValue('content_en');
     $desc = $contentBasic2 . $countVars2;
     $desc = preg_replace('/[\n\r]/','',$desc);
@@ -164,10 +168,12 @@ if ($curcontent->GetPropertyValue($description_block) != '') {
     $desclength = $this->GetPreference('length_title','30');
     $desc = preg_replace('/((\w+\W*){'.($desclength-1).'}(\w+))(.*)/', '${1}', $desc);
 } elseif ($this->GetPreference('auto_title','1') == 1) {
-    foreach ($contentVar as $key => $countVar2) {
-        $countVars2[] = $smarty->get_template_vars($countVar2);
+    if ($contentVar != '') {
+        foreach ($contentVar as $key => $countVar2) {
+            $countVars2[] = $smarty->get_template_vars($countVar2);
+        }
+        $countVars2 = join(' ', $countVars2);
     }
-    $countVars2 = join(' ', $countVars2);
     $contentBasic2 = $curcontent->GetPropertyValue('content_en');
     $desc = $contentBasic2 . $countVars2;
     $desc = preg_replace('/[\n\r]/','',$desc);
@@ -239,6 +245,13 @@ if ($this->GetPreference('allow_add',1) == 1) {
    $this->smarty->assign('closehead_title', $this->GetPreference('closehead_title','0'));
    $this->smarty->assign('additional_title', $this->GetPreference('additional_title',''));
    $this->smarty->assign('stylesheet_title', $this->GetPreference('stylesheet_title','0'));
+   $this->smarty->assign('jquery_title', $this->GetPreference('jquery_title','0'));
+   $this->smarty->assign('jquery_exclude', $this->GetPreference('jquery_exclude',''));
+   $this->smarty->assign('jquery_include', $this->GetPreference('jquery_include',''));
+   $this->smarty->assign('jquery_cnd', $this->GetPreference('jquery_cnd','false'));
+   $this->smarty->assign('jquery_ssl', $this->GetPreference('jquery_ssl','0'));
+   $this->smarty->assign('jquery_custom_root', $this->GetPreference('jquery_custom_root',''));
+   $this->smarty->assign('jquery_assign', $this->GetPreference('jquery_assign',''));
    $this->smarty->assign('compatible_title', $this->GetPreference('compatible_title','0'));
    $this->smarty->assign('compatibleie_title', $this->GetPreference('compatibleie_title','-1'));
    $this->smarty->assign('compatiblechrome_title', $this->GetPreference('compatiblechrome_title','-1'));
@@ -261,6 +274,5 @@ if (isset($params['module_message'])) {
 ///// PROCESS AND DISPLAY TEMPLATE /////
 
 echo $this->ProcessTemplate('metamax.tpl');
-//print_r($countVars);
 
 ?>
\ No newline at end of file
