@@ -16,6 +16,8 @@ $lang['none'] = 'None';
 $lang['upgraded'] = 'Module upgraded to version %s.';
 $lang['page_title_legend'] = 'Page title and description';
 $lang['html_title_legend'] = 'HTML options';
+$lang['css_title_legend'] = 'Stylesheet options';
+$lang['jquery_title_legend'] = 'Jquery options';
 $lang['additional_title_legend'] = 'Additional content';
 $lang['meta_title_legend'] = 'Meta tags';
 $lang['metaoptions_title_legend'] = 'Meta content';
@@ -26,6 +28,8 @@ $lang['bing_title_legend'] = 'Bing webmaster settings';
 $lang['tab_mod_general'] = 'General settings';
 $lang['tab_mod_html'] = 'HTML tag settings';
 $lang['tab_mod_meta'] = 'Page title & Meta information';
+$lang['tab_mod_css'] = 'Stylesheet settings';
+$lang['tab_mod_jquery'] = 'JQuery settings';
 $lang['tab_mod_keywords'] = 'Keyword settings';
 $lang['tab_mod_analytics'] = 'Analytics Account settings';
 $lang['tab_mod_bing'] = 'Bing Account settings';
@@ -76,7 +80,6 @@ $lang['lang_title'] = 'Include language';
 $lang['xmllang_title'] = 'Include XML language';
 $lang['openhead_title'] = 'Generate Opening Head Tag';
 $lang['closehead_title'] = 'Generate Closing Head Tag';
-$lang['stylesheet_title'] = 'Include &#123;cms_stylesheet} tag';
 $lang['compatible_title'] = 'Include X-UA-Compatible tag';
 $lang['compatibleie_title'] = 'IE version for compatibility tag';
 $lang['compatiblechrome_title'] = 'Chrome version for compatibility tag';
@@ -87,7 +90,22 @@ $lang['compatible_9'] = 'IE 9';
 $lang['compatible_edge'] = 'IE Edge';
 $lang['compatible_chrome'] = 'Chrome';
 $lang['additional_title'] = 'Additional content to appear in head';
+$lang['stylesheet_title'] = 'Include &#123;cms_stylesheet} tag';
+$lang['stylesheet_name'] = 'Name parameter';
+$lang['stylesheet_nocombine'] = 'No Combine parameter';
+$lang['stylesheet_https'] = 'Use https url';
+$lang['stylesheet_templateid'] = 'Template ID parameter';
+$lang['stylesheet_media'] = 'Media parameter';
 $lang['standard_title'] = 'Generate standard Meta Tags';
+$lang['jquery_title'] = 'Include &#123;cms_jquery} tag';
+$lang['jquery_exclude'] = 'Exclude parameter';
+$lang['jquery_include'] = 'Include parameter';
+$lang['jquery_cnd'] = 'CND parameter';
+$lang['jquery_ssl'] = 'SSL parameter';
+$lang['jquery_custom_root'] = 'Custom root parameter';
+$lang['jquery_assign'] = 'Assign parameter';
+$lang['jquery_true'] = 'True';
+$lang['jquery_false'] = 'False';
 $lang['dublin_title'] = 'Generate Dublin Core Meta Tags';
 $lang['opengraph_title'] = 'Generate OpenGraph Meta Tags (e.g. for Facebook Like Button)';
 $lang['publisher_title'] = 'Site publisher';
@@ -147,7 +165,11 @@ $lang['changelog'] = '<ul>
 <li>Version 1.6.8. 24 February 2012. Minor bug fix.</li>
 <li>Version 1.6.9. 25 February 2012. Bug fix #7638 and #7639.</li>
 <li>Version 1.6.9.1. 25 February 2012. Made PHP 5.2 compatible to fix bug #7638.</li>
-<li>Version 1.7. 26 February 2012. Added the ability to specify multiple content blocks from where pages keywords and descriptions are created from assigned variables.</li></ul>';
+<li>Version 1.7 26 February 2012. Added the ability to specify multiple content blocks from where pages keywords and descriptions are created from assigned variables.</li>
+<li>Version 1.7.1 26 February 2012. Minor bug fix.</li>
+<li>Version 1.7.2 26 February 2012. Minor bug fix.</li>
+<li>Version 1.7.3 27 February 2012. Added seperate cms_stylesheet and cms_jquery tabs.</li>
+<li>Version 1.7.3.1 27 February 2012. Minor bug fix.</li></ul>';
 $lang['help'] = '<h3>What Does This Do?</h3>
 <p>This module adds the ability to include additional Meta data, Analytics tracking code and other useful SEO information. It can also be used to generate Doctype and Head tags, replacing the entire head of your document.</p>
 <h3>How Do I Use It</h3>
